# Prompt Engineering Guide

Prompt engineering is a relatively new discipline for developing and optimizing prompts to efficiently use language models (LMs) for a wide variety of applications and research topics. Prompt engineering skills help to better understand the capabilities and limitations of large language models (LLMs). Researchers use prompt engineering to improve the capacity of LLMs on a wide range of common and complex tasks such as question answering and arithmetic reasoning. Developers use prompt engineering to design robust and effective prompting techniques that interface with LLMs and other tools.

Motivated by the high interest in developing with LLMs, we have created this new prompt engineering guide that contains all the latest papers, learning guides, lectures, references, and tools related to prompt engineering. 

Happy Prompting!

---
## Announcements / Updates

- 🌐 We now support [中文](https://www.promptingguide.ai/zh) and [English](https://www.promptingguide.ai/). Welcoming more translations.
- 🎉 We have launched new web version of the guide [here](https://www.promptingguide.ai/)
- 🎓 Partnered with Sphere to deliver a new course on [Prompt Engineering for LLMs](https://www.getsphere.com/cohorts/prompt-engineering-for-llms?source=github)
- 🔥 We reached #1 on Hacker News on 21 Feb 2023
- 🎉 The Prompt Engineering Lecture went live [here](https://youtu.be/dOxUroR57xs)

[Join our Discord](https://discord.gg/SKgkVT8BGJ)

[Follow us on Twitter](https://twitter.com/dair_ai)

[Subscribe to our Newsletter](https://nlpnews.substack.com/)

---
## Lecture

We have published a 1 hour lecture that provides a comprehensive overview of prompting techniques, applications, and tools.
- [Video Lecture](https://youtu.be/dOxUroR57xs)
- [Notebook with code](https://github.com/dair-ai/Prompt-Engineering-Guide/blob/main/notebooks/pe-lecture.ipynb)
- [Slides](https://github.com/dair-ai/Prompt-Engineering-Guide/blob/main/lecture/Prompt-Engineering-Lecture-Elvis.pdf)

---

## Guides
Please note that the guides below are now outdated. You can find the most up-to-date guides on our new website [https://www.promptingguide.ai/](https://www.promptingguide.ai/). 

- [Prompt Engineering - Introduction](/guides/prompts-intro.md)
- [Prompt Engineering - Basic Prompting](/guides/prompts-basic-usage.md)
- [Prompt Engineering - Advanced Prompting](/guides/prompts-advanced-usage.md)
- [Prompt Engineering - Applications](/guides/prompts-applications.md)
- [Prompt Engineering - ChatGPT](/guides/prompts-chatgpt.md)
- [Prompt Engineering - Adversarial Prompting](/guides/prompts-adversarial.md)
- [Prompt Engineering - Reliability](/guides/prompts-reliability.md)
- [Prompt Engineering - Miscellaneous Topics](/guides/prompts-miscellaneous.md)
- [Prompt Engineering - Papers](/pages/papers.en.mdx)
- [Prompt Engineering - Tools](/pages/tools.en.mdx)
- [Prompt Engineering - Datasets](/pages/datasets.en.mdx) 
- [Prompt Engineering - Additional Readings](/pages/readings.en.mdx)

---
If you are using the guide for your work, please cite us as follows:

```
@article{Saravia_Prompt_Engineering_Guide_2022,
author = {Saravia, Elvis},
journal = {https://github.com/dair-ai/Prompt-Engineering-Guide},
month = {12},
title = {{Prompt Engineering Guide}},
year = {2022}
}
```

## License

[MIT License](https://github.com/dair-ai/Prompt-Engineering-Guide/blob/main/LICENSE.md)


Feel free to open a PR if you think something is missing here. Always welcome feedback and suggestions. Just open an issue!
